@@ -2,15 +2,17 @@ package App::Ack::ConfigLoader;
 
 use strict;
 use warnings;
-use feature 'say';
+use 5.010;
 
 use App::Ack ();
 use App::Ack::ConfigDefault ();
 use App::Ack::ConfigFinder ();
-use App::Ack::Filter;
-use App::Ack::Filter::Collection;
-use App::Ack::Filter::Default;
+use App::Ack::Filter ();
+use App::Ack::Filter::Collection ();
+use App::Ack::Filter::Default ();
+use App::Ack::Filter::IsPath ();
 use Carp 1.04 ();
+use File::Spec 3.00 ();
 use Getopt::Long 2.38 ();
 use Text::ParseWords 3.1 ();
 
@@ -64,7 +66,7 @@ sub _generate_ignore_dir {
     return sub {
         my ( undef, $dir ) = @_;
 
-        $dir = App::Ack::remove_dir_sep( $dir );
+        $dir = _remove_directory_separator( $dir );
         if ( $dir !~ /:/ ) {
             $dir = 'is:' . $dir;
         }
@@ -107,6 +109,18 @@ sub _generate_ignore_dir {
     };
 }
 
+
+sub _remove_directory_separator {
+    my $path = shift;
+
+    state $dir_sep_chars = $App::Ack::is_windows ? quotemeta( '\\/' ) : quotemeta( File::Spec->catfile( '', '' ) );
+
+    $path =~ s/[$dir_sep_chars]$//;
+
+    return $path;
+}
+
+
 sub _process_filter_spec {
     my ( $spec ) = @_;
 
@@ -789,8 +803,7 @@ sub retrieve_arg_sources {
     };
 
     foreach my $file ( @files) {
-        my @lines = App::Ack::ConfigFinder::read_rcfile($file->{path});
-
+        my @lines = read_rcfile($file->{path});
         if ( @lines ) {
             push @arg_sources, {
                 name     => $file->{path},
@@ -801,13 +814,6 @@ sub retrieve_arg_sources {
         }
     }
 
-    if ( $ENV{ACK_OPTIONS} && !$noenv ) {
-        push @arg_sources, {
-            name     => 'ACK_OPTIONS',
-            contents => $ENV{ACK_OPTIONS},
-        };
-    }
-
     push @arg_sources, {
         name     => 'ARGV',
         contents => [ @ARGV ],
@@ -816,4 +822,34 @@ sub retrieve_arg_sources {
     return @arg_sources;
 }
 
+
+=head2 read_rcfile( $filename )
+
+Reads the contents of the .ackrc file and returns the arguments.
+
+=cut
+
+sub read_rcfile {
+    my $file = shift;
+
+    return unless defined $file && -e $file;
+
+    my @lines;
+
+    open( my $fh, '<', $file ) or App::Ack::die( "Unable to read $file: $!" );
+    while ( my $line = <$fh> ) {
+        chomp $line;
+        $line =~ s/^\s+//;
+        $line =~ s/\s+$//;
+
+        next if $line eq '';
+        next if $line =~ /^\s*#/;
+
+        push( @lines, $line );
+    }
+    close $fh or App::Ack::die( "Unable to close $file: $!" );
+
+    return @lines;
+}
+
 1; # End of App::Ack::ConfigLoader
