@@ -1,10 +1,11 @@
 package App::Ack::File;
 
-use App::Ack;
-
 use warnings;
 use strict;
 
+use App::Ack ();
+use File::Spec ();
+
 =head1 NAME
 
 App::Ack::File
@@ -97,48 +98,6 @@ sub open {
 }
 
 
-=head2 $file->needs_line_scan( \%opts )
-
-Tells if the file needs a line-by-line scan.  This is a big
-optimization because if you can tell from the outset that the pattern
-is not found in the file at all, then there's no need to do the
-line-by-line iteration.
-
-Slurp up an entire file up to 100K, see if there are any matches
-in it, and if so, let us know so we can iterate over it directly.
-If it's bigger than 100K or the match is inverted, we have to do
-the line-by-line, too.
-
-=cut
-
-sub needs_line_scan {
-    my $self  = shift;
-    my $opt   = shift;
-
-    return 1 if $opt->{v};
-
-    return 1 unless -f $self->{fh};
-
-    my $size = -s $self->{fh};
-    if ( $size == 0 ) {
-        return 0;
-    }
-    elsif ( $size > 100_000 ) {
-        return 1;
-    }
-
-    my $buffer;
-    my $rc = sysread( $self->{fh}, $buffer, $size );
-    if ( !defined($rc) && $App::Ack::report_bad_filenames ) {
-        App::Ack::warn( "$self->{filename}: $!" );
-        return 1;
-    }
-    return 0 unless $rc && ( $rc == $size );
-
-    return $buffer =~ /$opt->{regex}/mo;
-}
-
-
 =head2 $file->reset()
 
 Resets the file back to the beginning.  This is only called if
